==> haskell-arch-web-0.3.1-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-arch-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 arch-web
version:              0.3.1
visibility:           public
id:                   arch-web-0.3.1-SwwuR3LrpEFYQOREcVE7L
key:                  arch-web-0.3.1-SwwuR3LrpEFYQOREcVE7L
license:              MIT
copyright:            Copyright (c) berberman 2021
maintainer:           berberman <berberman@yandex.com>
author:               berberman
stability:            alpha
homepage:             https://github.com/berberman/arch-web
synopsis:             Arch Linux official and AUR web interface binding
description:
    Arch Linux official and AUR web interface binding.
    See README for details.

category:             Web
abi:                  b8dcf2ef6aa235e007ba4035e28fcda4
exposed:              True
exposed-modules:
    Web.ArchLinux Web.ArchLinux.API Web.ArchLinux.Types
    Web.ArchLinux.Types.Lens

hidden-modules:       Web.ArchLinux.Types.API
import-dirs:          /usr/lib/ghc-9.4.8/site-local/arch-web-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/arch-web-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/arch-web-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-arch-web
hs-libraries:         HSarch-web-0.3.1-SwwuR3LrpEFYQOREcVE7L
depends:
    aeson-2.1.2.1-JUxXPniSz0YG5YB65a9rRK base-4.17.2.1
    deriving-aeson-0.2.10-K9WpNshYPqrG4B3ANWaJKg exceptions-0.10.5
    http-client-0.7.17-6Vpdbpk3Ln7BXqc0zQ7YEB
    http-client-tls-0.3.6.4-7tZUghBa9qt8CEVGZ3Qxvr
    http-types-0.12.4-3U9Wv2ie0NhIMa2ncoKEKC
    lens-5.2.3-7xTAGVF8ixt9yux1447c6O mtl-2.2.2
    servant-0.20.2-M198Qbz1Py1RMtJkhCm2Y
    servant-client-0.20-BqeEn1ldPPl7PoCpYL88Op
    servant-client-core-0.20.2-DJeG7Nktop6De1o0LztPFb text-2.0.2
    time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-arch-web/html/arch-web.haddock
haddock-html:         /usr/share/doc/haskell-arch-web/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-arch-web-0.3.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-arch-web.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 arch-web
version:              0.3.1
visibility:           public
id:                   arch-web-0.3.1-LX1owzNChQm6now9iHY4ov
key:                  arch-web-0.3.1-LX1owzNChQm6now9iHY4ov
license:              MIT
copyright:            Copyright (c) berberman 2021
maintainer:           berberman <berberman@yandex.com>
author:               berberman
stability:            alpha
homepage:             https://github.com/berberman/arch-web
synopsis:             Arch Linux official and AUR web interface binding
description:
    Arch Linux official and AUR web interface binding.
    See README for details.

category:             Web
abi:                  e2de8401ba28240d05f6f902f4031416
exposed:              True
exposed-modules:
    Web.ArchLinux Web.ArchLinux.API Web.ArchLinux.Types
    Web.ArchLinux.Types.Lens

hidden-modules:       Web.ArchLinux.Types.API
import-dirs:          /usr/lib/ghc-9.4.8/site-local/arch-web-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/arch-web-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/arch-web-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-arch-web
hs-libraries:         HSarch-web-0.3.1-LX1owzNChQm6now9iHY4ov
depends:
    aeson-2.1.2.1-4CVR04TmBAJCS7ApojWVjB base-4.17.2.1
    deriving-aeson-0.2.10-H4MAWOxIhx51Ps6n17djle exceptions-0.10.5
    http-client-0.7.17-1TeKHeaIXcm1IagLpQyCg9
    http-client-tls-0.3.6.4-4NRNQJUzLEz9Lfo37wsm7O
    http-types-0.12.4-IKMPl2KcAdO7QMS7LRjciE
    lens-5.2.3-EqD4LSjkO4yUdDVMPM2Ph mtl-2.2.2
    servant-0.20.2-CZnY81TcoPaGu39vbqVUPJ
    servant-client-0.20-BSfQ1weUGy83QjJJRPjJPC
    servant-client-core-0.20.2-AFiUzzM3pw34Q7JOOlqOj0 text-2.0.2
    time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-arch-web/html/arch-web.haddock
haddock-html:         /usr/share/doc/haskell-arch-web/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
